@@ -24,6 +24,8 @@ import (
 	"k8s.io/kubernetes/pkg/controller"
 	"k8s.io/kubernetes/pkg/registry/core/service/allocator"
 	"k8s.io/kubernetes/pkg/registry/core/service/ipallocator"
+
+	workqueuemetrics "github.com/openshift/openshift-controller-manager/pkg/metrics"
 )
 
 const (
@@ -91,6 +93,8 @@ func NewIngressIPController(services cache.SharedIndexInformer, kc kclientset.In
 		recorder:   recorder,
 	}
 
+	workqueuemetrics.NewNamedWorkQueueMetrics("ingressip")
+
 	ic.cache = services.GetStore()
 	ic.controller = services.GetController()
 	services.AddEventHandlerWithResyncPeriod(
